@@ -1,6 +1,6 @@
 /*******************************************************************/
 /*  slibtool: a strong libtool implementation, written in C        */
-/*  Copyright (C) 2016--2024  SysDeer Technologies, LLC            */
+/*  Copyright (C) 2016--2025  SysDeer Technologies, LLC            */
 /*  Released under the Standard MIT License; see COPYING.SLIBTOOL. */
 /*******************************************************************/
 
@@ -131,6 +131,9 @@ static struct slbt_exec_ctx_impl * slbt_exec_ctx_alloc(
 		size += exts * SLBT_ECTX_LIB_EXTRAS;
 	}
 
+	/* -lsltdl (--prefer-sltdl impl.) */
+	size += 8;
+
 	/* string buffers: args, shadow */
 	if (!(args = malloc(size)))
 		return 0;
@@ -629,6 +632,11 @@ int  slbt_ectx_get_exec_ctx(
 
 	}
 
+	/* -lsltdl (--prefer-sltdl impl.) */
+	ictx->lsltdl = ch;
+	strcpy(ch,"-lsltdl");
+	ch += 8;
+
 	/* dlopen, dlpreopen */
 	if ((dlopenv = idctx->dlopenv), (dlactxv = ictx->dlactxv)) {
 		if (slbt_ar_get_varchive_ctx(dctx,dlactxv) < 0)
